==> haskell-persistent-mysql-2.13.1.5-63-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-mysql
version:              2.13.1.5
visibility:           public
id:                   persistent-mysql-2.13.1.5-YpQKpuxyDt6sMymz5es5B
key:                  persistent-mysql-2.13.1.5-YpQKpuxyDt6sMymz5es5B
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  b94af2a8690f1dba9029aa04c1f2de6e
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.1.5-YpQKpuxyDt6sMymz5es5B
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1
    blaze-builder-0.4.4-1ntb6RP4OewIlLWEkSeIAR bytestring-0.11.5.3
    conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1 containers-0.6.7
    monad-logger-0.3.42-JkMW6I4lRDO9lIgdCqxRwW
    mysql-0.2.1-D5LpJU8LILP48cJYVQsv03
    mysql-simple-0.4.9-BJUOjjh8lAuENl0j1wGXRm
    persistent-2.14.5.2-GPWHCW8fdRqGAAF6p19mHm
    resource-pool-0.2.3.2-5oQsv6yyKmlCMdNDJD8QG7
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP text-2.0.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-mysql-2.13.1.5-85-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-mysql
version:              2.13.1.5
visibility:           public
id:                   persistent-mysql-2.13.1.5-4A21bUreflT6rLQS694gI8
key:                  persistent-mysql-2.13.1.5-4A21bUreflT6rLQS694gI8
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  4bc8f6656826a24995f03a5dff3f9461
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-mysql-2.13.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.1.5-4A21bUreflT6rLQS694gI8
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1
    blaze-builder-0.4.4.1-1AsqmJqbexUDW45IoYp4gz bytestring-0.11.5.3
    conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3 containers-0.6.7
    monad-logger-0.3.42-LuCAjjjmxzACtBdHBvTKdG
    mysql-0.2.1-LVKyVCd8LMJm9c8fMOdLh
    mysql-simple-0.4.9-5RvQbue5oYiEWG6xMe5Cr3
    persistent-2.14.5.2-4XQ911owVSTIyWoNtMmSaI
    resource-pool-0.2.3.2-IwokjjpbTKCEUx26uJ9tBR
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl text-2.0.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
